"use server";

import { requestGetFetch, requestPostFetch } from "@/utils/fetch";
import { getServerSession, Session } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";


export async function casesRequestList(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const paramsArray = searchParams && Object.entries(searchParams);

    const queryString = paramsArray && paramsArray.map(([key, value]) => `${key}=${value}`).join('&');

    const path = 'v1/cases' + `?${queryString}`;

    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}

export async function getCaseById(id: number) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    const path = `v1/cases/${id}`;
    const response = await requestGetFetch({
      path,
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });
    return response.data || [];
  } catch (error) {
    throw error;
  }
}


export async function editCaseRequest(payload: { userId: string; data: any }) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/cases/" + payload?.userId;
    const response = await requestGetFetch({
      path,
      options: {
        method: "PATCH",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        body: JSON.stringify(payload?.data),
        cache: 'no-store',
      },
    });
    return response;
  } catch (error: any) {
    throw new Error(error.message);
  }
}


export async function createCaseRequest(payload: any) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/cases";

    const response = await requestPostFetch({
      path,
      data: { ...payload },
      token: token,
    });

    return response
  } catch (error: any) {
    throw new Error(error.message);
  }
}


export async function deleteCase(id: number | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/cases/" + id;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Delete",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}
